@@ -56,10 +56,11 @@ if (run.integration.tests) {
                     name="foo"), no.match)
                 expect_true(is.CA(makeArray(c("mr_1", "mr_2", "mr_3"),
                     dataset=ds, name="foo")))
-                skip(with(test.dataset(df, "notds"), {
+                skip("Errors, but with wrong error condition")
+                with(test.dataset(df, "notds"), {
                     expect_error(makeArray(ds[1:3], dataset=notds,
                         name="arrayVar"), ds.mismatch)
-                }), "Errors, but does so unexpectedly")
+                })
             })
         })
         
@@ -134,10 +135,6 @@ if (run.integration.tests) {
                     expect_error(makeMR(pattern="mr_[123]", dataset=ds,
                         name="arrayVar", selections="Not a Selection!"),
                         not.categorical)
-                    skip(with(test.dataset(df, "notds"), {
-                        expect_error(makeMR(ds[1:3], dataset=notds,
-                            name="arrayVar"), ds.mismatch)
-                    }), "userdataset problem?")
                     cast.these <- grep("mr_", names(ds))
                     ds[cast.these] <- lapply(ds[cast.these],
                         castVariable, "categorical")
@@ -146,6 +143,11 @@ if (run.integration.tests) {
                         invalid.selection)
                     expect_error(makeMR(pattern="mr_[123]", dataset=ds,
                         name="arrayVar"), no.selections)
+                    skip("Errors, but with Error in match(x, table, nomatch = 0L) : \n  'match' requires vector arguments\n")
+                    with(test.dataset(df, "notds"), {
+                        expect_error(makeMR(ds[1:3], dataset=notds,
+                            name="arrayVar", selections="1.0"), ds.mismatch)
+                    })
                 })
             })
         })
